from typing import Dict, List

from ProjectState import ProjectState

SITE_CLUSTER_DEFAULT = "Whole Cluster"


class GisDataState:
    def __init__(self):
        self._regions: List[Dict] = []
        self._clusters: List[Dict] = []
        self._siteClusters: List[Dict] = []

    def hasSiteClusterData(self):
        return len(self._siteClusters) > 0

    def hasClusterData(self):
        return len(self._clusters) > 0

    def getRegionData(self):
        return self._regions

    def setRegionData(self, data: List[Dict]):
        self._regions = data

        self._clusters = []
        self._siteClusters = []

    def getRegionNames(self) -> List[str]:
        return [region["nameToDisplay"] for region in self._regions]

    def getOopForRegionWithName(self, regionName):
        for region in self._regions:
            if region["nameToDisplay"] == regionName:
                return region["asOop"]

    def getClusterData(self):
        return self._clusters

    def setClusterData(self, data: List[Dict]):
        self._clusters = data

        self._siteClusters = []

    def getClusterNames(self) -> List[str]:
        return [cluster["nameToDisplay"] for cluster in self._clusters]

    def getSiteClusterData(self):
        return self._siteClusters

    def setSiteClusterData(self, data: List[Dict]):
        self._siteClusters = data

    def getSiteClusterNames(self) -> List[str]:
        return [siteCluster["nameToDisplay"] for siteCluster in self._siteClusters]

    def getOopForClusterWithName(self, projectState: ProjectState):
        if projectState.siteClusterName == SITE_CLUSTER_DEFAULT:
            for cluster in self._clusters:
                if cluster["nameToDisplay"] == projectState.clusterName:
                    return cluster["asOop"]
        else:
            for cluster in self._siteClusters:
                if cluster["nameToDisplay"] == projectState.siteClusterName:
                    return cluster["asOop"]
