import csv
import os.path
import urllib.parse

from qgis.core import QgsVectorLayer

from Helper import removeLongPathPrefixFromPath

REVISION_FILE_NAME = "revision.csv"


def createRevisionCSV(clusterDirPath: str):
    csvFile = os.path.join(clusterDirPath, REVISION_FILE_NAME)
    if not os.path.exists(csvFile):
        with open(csvFile, "w") as csvfile:
            fieldnames = ["Revision:", "Bearbeiter:", "Kommentar:"]
            writer = csv.writer(
                csvfile,
                delimiter=";",
                lineterminator="\n",
                quotechar='"',
                quoting=csv.QUOTE_MINIMAL,
            )
            writer.writerow(fieldnames)
            row1 = ["1", "", ""]
            writer.writerow(row1)


def addRevisionCSVLayer(qgisProject, clusterDirPath: str):
    """CSV file path notation needed to be file:///path?csvOptions otherwise the vector layer is invalid"""
    csvFilePath = os.path.join(
        removeLongPathPrefixFromPath(clusterDirPath), REVISION_FILE_NAME
    )

    csvOptions = "type=csv&delimiter=;&geomType=none&trimFields=yes&skipEmptyFields=yes"
    csvUri = f"file:///{urllib.parse.quote(csvFilePath)}?{csvOptions}"

    csvLayer = QgsVectorLayer(csvUri, "Revision", "delimitedtext")
    csvLayer.setKeywordList('{"type": "RimoLayer", "name": "revision"}')
    qgisProject.addMapLayer(csvLayer, True)
