import json
from typing import Dict, List

import requests

QGIS_API_CONTROLLER_RELATIVE_URL = "api/MIT/SDMeteorQGISController"


def sendLoginRequest(rimoUrl, userName, password, version):
    r = requests.post(
        rimoUrl + QGIS_API_CONTROLLER_RELATIVE_URL,
        data=json.dumps(
            {
                "method": "verifyUser",
                "user": userName,
                "password": password,
                "version": version,
            }
        ),
    )
    return json.loads(r.text)


def getRegions(rimoUrl, oop, pluginVersion, userOop, token) -> List[Dict] or None:
    r = requests.post(
        rimoUrl + QGIS_API_CONTROLLER_RELATIVE_URL,
        data=json.dumps(
            {
                "method": "getRegionsFromTenant",
                "Oop": oop,
                "version": pluginVersion,
                "userOop": userOop,
                "token": token,
            }
        ),
    )
    data = json.loads(r.text)
    data = sorted(data, key=lambda k: k["name"])
    return data


def getClusterData(rimoUrl, oop, pluginVersion, userOop, token):
    r = requests.post(
        rimoUrl + QGIS_API_CONTROLLER_RELATIVE_URL,
        data=json.dumps(
            {
                "method": "getClustersFromRegion",
                "Oop": oop,
                "version": pluginVersion,
                "userOop": userOop,
                "token": token,
            }
        ),
    )
    data = json.loads(r.text)
    data = sorted(data, key=lambda k: k["name"])
    return data


def getSiteClusterData(rimoUrl, oop, pluginVersion, userOop, token):
    r = requests.post(
        rimoUrl + QGIS_API_CONTROLLER_RELATIVE_URL,
        data=json.dumps(
            {
                "method": "getSiteClustersFromClusters",
                "Oop": oop,
                "version": pluginVersion,
                "userOop": userOop,
                "token": token,
            }
        ),
    )
    data = json.loads(r.text)
    data = sorted(data, key=lambda k: k["name"])
    return data


def getBackboneRegionData(rimoUrl, clusterOop, token):
    apiUrl = f"{rimoUrl}{QGIS_API_CONTROLLER_RELATIVE_URL}"
    r = requests.post(
        apiUrl,
        data=json.dumps(
            {"method": "getBackboneRegion", "Oop": clusterOop, "token": token}
        ),
    )
    data = json.loads(r.text)
    return data


def getRimoComposerData(rimoUrl, tenantId, clusterOop, token):
    url = f"{rimoUrl}geo/{tenantId}/{clusterOop}/exportMetaInfo?token={token}"
    r = requests.get(url)
    data = json.loads(r.text)
    return data
